@@ -4,16 +4,16 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.049 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  2.052 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base  2.049 ;
-use IO::Uncompress::Adapter::Lzf  2.049 ;
+use IO::Uncompress::Base  2.052 ;
+use IO::Uncompress::Adapter::Lzf  2.052 ;
 
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzfError);
 
-$VERSION = '2.049';
+$VERSION = '2.052';
 $UnLzfError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -587,7 +587,7 @@ The string '-' can be used as an alias for standard input.
 =item A scalar reference 
 
 If C<$input> is a scalar reference, the compressed data will be read from
-C<$$output>.
+C<$$input>.
 
 =back
 
